/*!
 * vue-window v1.0.0
 * (c) 2016 mark fluehmann
 * Released under the MIT License.
 */
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    global.VueWindow = factory();
}(this, function () { 'use strict';

    /* export default for holding the Vue reference */
    var instance = {};

    /**
    * Notify constructor
    * @param {Object} [options]
    */
    var WindowSize = (function () {
        function WindowSize() {

            /* global references */

            /* option defaults */
            var defaults = {
            };

            /* extend defaults with given options */
            this.options = {};
            if (arguments[0] && typeof arguments[0] === "object") {
                this.options = extendDefaults(defaults, arguments[0]);
            }
        }

        /**
         * Extend defaults with given custom options
         * @param  object source       WindowSize Object defaults
         * @param  object properties   custom options
         * @return object              combined new defaults
         */
        function extendDefaults(source, properties) {
            for (var property in properties) {
                if (properties.hasOwnProperty(property)) {
                    source[property] = properties[property];
                }
            }
            return source;
        }

        return WindowSize;

    })();

    function applyOverride (Vue) {
        var _util = Vue.util;

        /* override Vue's init */
        var init = Vue.prototype._init;
        Vue.prototype._init = function (options) {
             init.call(this, options);
        };

        /* override Vue's destroy process */
        var destroy = Vue.prototype._destroy;
        Vue.prototype._destroy = function () {
            destroy.apply(this, arguments);
        };
    };

    function registerMixins(Vue) {
        Vue.mixin({
            data: function() {
                return {
                    window: {
                        viewport: {
                            height: 0,
                            width: 0,
                        },
                        page: {
                            height: 0,
                            width: 0,           
                        }
                    }
                }
            },
            ready: function() {
                window.addEventListener("load", this.getViewportSize);
                window.addEventListener("resize", this.getViewportSize);
            },
            methods: {
                getViewportSize: function () {
                    var body = document.querySelector("body");
                    var page = document.querySelector(".content")
                    this.window.viewport.height = body.clientHeight;                
                    this.window.viewport.width =  body.clientWidth;             
                    this.window.page.height = page.clientHeight;
                    this.window.page.width = page.clientWidth;
                }
            }
        });
    };

    /* Installation */
    WindowSize.installed = false;
    WindowSize.install = function (Vue) {
        var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

        if (WindowSize.installed) {
          warn('already installed.');
          return;
        }

        //applyOverride(Vue);
        registerMixins(Vue);
 
        instance.Vue = Vue;
        WindowSize.installed = true;
    };

    /* set plugin version */
    WindowSize.version = '1.0.0';

    /* auto install */
    if (typeof window !== 'undefined' && window.Vue) {
        window.Vue.use(WindowSize);
    }

    return WindowSize;

}));